# coding: utf-8

__title__ = 'leselys'
__version__ = '0.1.6'
__author__ = 'Geoffrey Lehée'
__license__ = ''
__copyright__ = 'Copyright 2013 Geoffrey Lehée'

from leselys.core import Core

core = Core()
